---
title: <span class="badge object-type-scalar"></span> CubicMeter
---
# <span class="badge object-type-scalar"></span> CubicMeter

Volume: cubic meter

## Definition

```python
# Volume: cubic meter
CubicMeter: typing.Literal["m3"] = "m3"
```
